@@ -33,6 +33,7 @@ from stat import *
 import time
 import datetime
 import calendar
+import locale
 import email.utils as eut
 import pynotify
 import dbus
@@ -50,6 +51,10 @@ class account():
     _MCE_SERVICE = 'com.nokia.mce'
     _MCE_REQUEST_PATH = '/com/nokia/mce/request'
     _MCE_REQUEST_IF = 'com.nokia.mce.request'
+    _ICD_SERVICE = 'com.nokia.icd'
+    _ICD_REQUEST_PATH = '/com/nokia/icd'
+    _ICD_REQUEST_IF = 'com.nokia.icd.connect'
+    _CONNECTION = '[ANY]'
     _ENABLE_LED = 'req_led_pattern_activate'
     _DISABLE_LED = 'req_led_pattern_deactivate'
     _VIBRATE  = 'req_vibrator_pattern_activate'
@@ -61,7 +66,8 @@ class account():
     def __init__(self, osso_c, accData, controller):
         pynotify.init("Witter")
         self.bus = dbus.SystemBus()
-
+        
+        locale.setlocale(locale.LC_ALL,'en_US')
         self.controller = controller
         #these store all the data associated with this accounts tweets
         # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source, pic, formatted_tweet
@@ -176,9 +182,11 @@ class account():
         return self.userhistorystore
 
     def getTweets(self, auto=0, older=False, get_count=20, * args):
+               
         if (self.api == None):
             if (self.connect() != True):
                 return
+            
         print "getting tweets with " + self.accountdata.username
         print "base url = " + self.accountdata.baseUrl
         print "base url of api object = " + self.api.GetBaseUrl()
@@ -196,9 +204,10 @@ class account():
             else:
                 if self.accountdata.oldest_id == None:
                     data = self.api.GetFriendsTimeline(count=get_count)
+                    print "fetching retweets to user"
                     rtdata = self.api.GetRetweets_to_user(count=get_count)
                 else:
-                    print "refreshing prior to" + str(self.accountdata.oldest_id)
+                    print "refreshing retweets prior to" + str(self.accountdata.oldest_id)
                     data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count)
                     rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
             data += rtdata
@@ -907,6 +916,33 @@ class account():
             note.system_note_dialog(msg)
             print msg
 
+    def newRetweet(self, id):
+        #performs a 'newstyle' retweet for the specific tweet id
+        print "retweeting "+str(id)
+        try:
+            self.api.reTweet(long(id))
+            note = osso.SystemNote(self.osso_c)
+            result = note.system_note_infoprint("ReTweeted Successfully")
+        
+        except IOError, e:
+            print "error"
+            msg = 'Error rewteeting ' + str(id) + ' '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+            print msg
+        
     def escapeText(self, text):
         #switch certain chars for escape sequences
         text = text.replace("&", "&amp;")
@@ -1104,7 +1140,7 @@ class account():
                     msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
                 except ValueError, e:
                     print e 
-                    print "returning datestamp for now failed to parse >" + timestr + "<"
+                    print "returning datestamp for now failed to parse >" + timestr + "< stripped to: >" +strippedDate+"<"
                     print "expected something in the form >Thu Aug 26 12:00:00 +0000 2010<"
                     return datetime.datetime.today()
 
