@@ -1086,20 +1086,20 @@ class Witter():
     def _on_orientation_signal(self, orientation, stand, face, x, y, z):
          if (orientation == 'portrait'):
             print "switching to portrait"
+            self.ui.orientation=orientation
             self.ui.cell.set_property('wrap-width', 400)
             self.ui.icon_size = 30
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
-            #print "show portrait keyboard"
-            #self.ui.show_portrait_keyboard()
-            #print "keybaord should be showing"
+            
          if (orientation == 'landscape'):
             print "switching to landscape"
+            self.ui.orientation=orientation
             self.ui.cell.set_property('wrap-width', 730)
             self.ui.icon_size = 48
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
-            #self.ui.hide_portrait_keyboard()
+            self.ui.hide_portrait_keyboard()
          print "refresh current view"
          curView = self.ui.getCurrentView()  
          if (curView == self.ui.TIMELINE_VIEW):
